struct VarLookupKey<'a>(&'a [NormalizedCoord]);Expand description
Lookup key for variable font caches (borrowed version).
Tuple Fields
0: &'a [NormalizedCoord]Trait Implementations
Sourceimpl<'a> Clone for VarLookupKey<'a>
impl<'a> Clone for VarLookupKey<'a>
Sourcefn clone(&self) -> VarLookupKey<'a>
fn clone(&self) -> VarLookupKey<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for VarLookupKey<'a>
impl<'a> Debug for VarLookupKey<'a>
Sourceimpl Equivalent<SmallVec<[F2Dot14; 4]>> for VarLookupKey<'_>
impl Equivalent<SmallVec<[F2Dot14; 4]>> for VarLookupKey<'_>
Sourcefn equivalent(&self, other: &SmallVec<[NormalizedCoord; 4]>) -> bool
fn equivalent(&self, other: &SmallVec<[NormalizedCoord; 4]>) -> bool
Checks if this value is equivalent to the given key. Read more
Sourceimpl From<VarLookupKey<'_>> for SmallVec<[NormalizedCoord; 4]>
impl From<VarLookupKey<'_>> for SmallVec<[NormalizedCoord; 4]>
Sourcefn from(key: VarLookupKey<'_>) -> Self
fn from(key: VarLookupKey<'_>) -> Self
Converts to this type from the input type.
Sourceimpl<'a> Hash for VarLookupKey<'a>
impl<'a> Hash for VarLookupKey<'a>
Sourceimpl<'a> PartialEq for VarLookupKey<'a>
impl<'a> PartialEq for VarLookupKey<'a>
Sourcefn eq(&self, other: &VarLookupKey<'a>) -> bool
fn eq(&self, other: &VarLookupKey<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'a> Copy for VarLookupKey<'a>
impl<'a> Eq for VarLookupKey<'a>
impl<'a> StructuralPartialEq for VarLookupKey<'a>